==> kubernetes-model-policy-5.11.1-sources.jar: io/fabric8/kubernetes/api/model/policy/v1beta1/PodDisruptionBudgetStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.policy.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PodDisruptionBudgetStatusBuilder extends io.fabric8.kubernetes.api.model.policy.v1beta1.PodDisruptionBudgetStatusFluentImpl<io.fabric8.kubernetes.api.model.policy.v1beta1.PodDisruptionBudgetStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.policy.v1beta1.PodDisruptionBudgetStatus,io.fabric8.kubernetes.api.model.policy.v1beta1.PodDisruptionBudgetStatusBuilder>{
  public PodDisruptionBudgetStatusBuilder() {
    this(false);
  }
  public PodDisruptionBudgetStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new PodDisruptionBudgetStatus(), validationEnabled);
  }
  public PodDisruptionBudgetStatusBuilder(io.fabric8.kubernetes.api.model.policy.v1beta1.PodDisruptionBudgetStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public PodDisruptionBudgetStatusBuilder(io.fabric8.kubernetes.api.model.policy.v1beta1.PodDisruptionBudgetStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PodDisruptionBudgetStatus(), validationEnabled);
  }
  public PodDisruptionBudgetStatusBuilder(io.fabric8.kubernetes.api.model.policy.v1beta1.PodDisruptionBudgetStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.policy.v1beta1.PodDisruptionBudgetStatus instance) {
    this(fluent, instance, false);
  }
  public PodDisruptionBudgetStatusBuilder(io.fabric8.kubernetes.api.model.policy.v1beta1.PodDisruptionBudgetStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.policy.v1beta1.PodDisruptionBudgetStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withCurrentHealthy(instance.getCurrentHealthy()); 
    fluent.withDesiredHealthy(instance.getDesiredHealthy()); 
    fluent.withDisruptedPods(instance.getDisruptedPods()); 
    fluent.withDisruptionsAllowed(instance.getDisruptionsAllowed()); 
    fluent.withExpectedPods(instance.getExpectedPods()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PodDisruptionBudgetStatusBuilder(io.fabric8.kubernetes.api.model.policy.v1beta1.PodDisruptionBudgetStatus instance) {
    this(instance,false);
  }
  public PodDisruptionBudgetStatusBuilder(io.fabric8.kubernetes.api.model.policy.v1beta1.PodDisruptionBudgetStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withCurrentHealthy(instance.getCurrentHealthy()); 
    this.withDesiredHealthy(instance.getDesiredHealthy()); 
    this.withDisruptedPods(instance.getDisruptedPods()); 
    this.withDisruptionsAllowed(instance.getDisruptionsAllowed()); 
    this.withExpectedPods(instance.getExpectedPods()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.policy.v1beta1.PodDisruptionBudgetStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.policy.v1beta1.PodDisruptionBudgetStatus build() {
    PodDisruptionBudgetStatus buildable = new PodDisruptionBudgetStatus(fluent.getConditions(),fluent.getCurrentHealthy(),fluent.getDesiredHealthy(),fluent.getDisruptedPods(),fluent.getDisruptionsAllowed(),fluent.getExpectedPods(),fluent.getObservedGeneration());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodDisruptionBudgetStatusBuilder that = (PodDisruptionBudgetStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-policy-6.1.1-sources.jar: io/fabric8/kubernetes/api/model/policy/v1beta1/PodDisruptionBudgetStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.policy.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PodDisruptionBudgetStatusBuilder extends PodDisruptionBudgetStatusFluentImpl<PodDisruptionBudgetStatusBuilder> implements VisitableBuilder<PodDisruptionBudgetStatus,PodDisruptionBudgetStatusBuilder>{
  public PodDisruptionBudgetStatusBuilder() {
    this(false);
  }
  public PodDisruptionBudgetStatusBuilder(Boolean validationEnabled) {
    this(new PodDisruptionBudgetStatus(), validationEnabled);
  }
  public PodDisruptionBudgetStatusBuilder(PodDisruptionBudgetStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public PodDisruptionBudgetStatusBuilder(PodDisruptionBudgetStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PodDisruptionBudgetStatus(), validationEnabled);
  }
  public PodDisruptionBudgetStatusBuilder(PodDisruptionBudgetStatusFluent<?> fluent,PodDisruptionBudgetStatus instance) {
    this(fluent, instance, false);
  }
  public PodDisruptionBudgetStatusBuilder(PodDisruptionBudgetStatusFluent<?> fluent,PodDisruptionBudgetStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withCurrentHealthy(instance.getCurrentHealthy()); 
    fluent.withDesiredHealthy(instance.getDesiredHealthy()); 
    fluent.withDisruptedPods(instance.getDisruptedPods()); 
    fluent.withDisruptionsAllowed(instance.getDisruptionsAllowed()); 
    fluent.withExpectedPods(instance.getExpectedPods()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PodDisruptionBudgetStatusBuilder(PodDisruptionBudgetStatus instance) {
    this(instance,false);
  }
  public PodDisruptionBudgetStatusBuilder(PodDisruptionBudgetStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withCurrentHealthy(instance.getCurrentHealthy()); 
    this.withDesiredHealthy(instance.getDesiredHealthy()); 
    this.withDisruptedPods(instance.getDisruptedPods()); 
    this.withDisruptionsAllowed(instance.getDisruptionsAllowed()); 
    this.withExpectedPods(instance.getExpectedPods()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  PodDisruptionBudgetStatusFluent<?> fluent;
  Boolean validationEnabled;
  public PodDisruptionBudgetStatus build() {
    PodDisruptionBudgetStatus buildable = new PodDisruptionBudgetStatus(fluent.getConditions(),fluent.getCurrentHealthy(),fluent.getDesiredHealthy(),fluent.getDisruptedPods(),fluent.getDisruptionsAllowed(),fluent.getExpectedPods(),fluent.getObservedGeneration());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
